#!/usr/bin/env python

# The Python version of qwt-0.3/examples/curvedemo1/curvdemo1.cpp

# This examples demonstrate the use of keyword arguments in constructors, like:
#
# instance = ClassName(keyword1 = value1, keyword2 = value2, ..).
#
# Any method name can be used as a keyword. The value is a Python object,
# whose type depend on the method name (the object can be a tuple, if the
# method takes more than one argument).
#
# The keyword arguments feature is enabled by post-processing sip-generated
# *.py files with the python script post_sip.py.
#
# Warning: this feature is a HACK, only working in constructors!
# Qt's Designer and pyuic don't know about keyword arguments.
# If you code by hand, keyword arguments allow for shorter code.


import glob, os, sys

# The next statements assure importation of qwt from the
# local source tree. This is useful for debugging and testing.
globs = glob.glob('../build/lib.*/qwt')
if globs:                               # found PyQwt modules made by distutils
    sys.path.insert(0, os.path.split(globs[0])[0])

from qt import *
from qwt import *
from Numeric import *

SIZE=27

class CurveDemo(QFrame):

    def __init__(self, *args):
        apply(QFrame.__init__, (self,) + args)

        self.setFrameStyle(QFrame.Box | QFrame.Raised)
        self.setLineWidth(2)
        self.setMidLineWidth(3)

        # make curves with different styles
        self.curves = []
        # curve 0
        self.curves.append(QwtCurve(
            setPen = QPen(Qt.darkGreen), setStyle = QwtCurve.Spline,
            setSymbol = QwtSymbol(QwtSymbol.Cross, QBrush(),
                                  QPen(Qt.black), QSize(5, 5))))
        # curve 1
        self.curves.append(QwtCurve(
            setPen = QPen(Qt.red), setStyle = QwtCurve.Sticks,
            setSymbol = QwtSymbol(QwtSymbol.Ellipse, QBrush(Qt.yellow),
                                  QPen(Qt.blue), QSize(5, 5))))
        # curve 2
        self.curves.append(QwtCurve(
            setPen = QPen(Qt.darkBlue), setStyle = QwtCurve.Lines))
        # curve 3
        self.curves.append(
            QwtCurve(setPen = QPen(Qt.darkCyan), setStyle = QwtCurve.Steps))
        # curve 4
        self.curves.append(QwtCurve(
            setStyle = QwtCurve.NoCurve,
            setSymbol = QwtSymbol(QwtSymbol.XCross, QBrush(),
                                  QPen(Qt.darkMagenta), QSize(5, 5))))

        # attach data, using Numeric
        self.x = arrayrange(0, 10.0, 10.0/SIZE)
        self.y = sin(self.x)*cos(2*self.x)
        for curve in self.curves:
            curve.setData(self.x, self.y)
            curve.setRange(-0.5, 10.5, 0, -1.1, 1.1, 0)


    def drawContents(self, painter):
        # draw curves
        r = self.contentsRect()
        dy = r.height()/len(self.curves)
        r.setHeight(dy)
        for curve in self.curves:
            curve.draw(painter, r)
            r.moveBy(0, dy)
        # draw titles
        r = self.contentsRect()
        r.setHeight(dy)
        painter.setFont(QFont('Helvetica', 8))
        painter.setPen(Qt.black)
        titles = [ 'Style: Spline, Symbol: Cross',
                   'Style: Sticks, Symbol: Ellipse',
                   'Style: Lines, Symbol: None',
                   'Style: Steps, Symbol: None',
                   'Style: NoCurve, Symbol: XCross' ]
        for title in titles:
            painter.drawText(
                0, r.top(), r.width(), painter.fontMetrics().height(),
                Qt.AlignTop | Qt.AlignHCenter, title)
            r.moveBy(0, dy)

# Admire!         
app = QApplication(sys.argv)
demo = CurveDemo()
app.setMainWidget(demo)
demo.resize(300, 600)
demo.show()
app.exec_loop()
