#!/usr/bin/env python

# The Python version of qwt-0.3/examples/simple_plot/simple.cpp

import glob, os, sys

# The next statements assure importation of qwt from the
# local source tree. This is useful for debugging and testing.
globs = glob.glob('../build/lib.*/qwt')
if globs:                               # found PyQwt modules made by distutils
    sys.path.insert(0, os.path.split(globs[0])[0])

from qt import *
from qwt import *
from Numeric import *

class SimpleDemo(QWidget):

    def __init__(self, *args):
        apply(QWidget.__init__, (self,) + args)

	# make a QwtPlot widget
	self.plot = QwtPlot('A Simple PyQwtPlot Demonstration', self)

	# calculate 3 NumPy arrays
        x = arrayrange(0.0, 10.0, 0.1)
        y = sin(x)
        z = cos(x)
	
	# insert a few curves
	cSin = self.plot.insertCurve('y = sin(x)')
	cCos = self.plot.insertCurve('y = cos(x)')
	
	# set curve styles
	self.plot.setCurvePen(cSin, QPen(Qt.red))
	self.plot.setCurvePen(cCos, QPen(Qt.blue))
	
	# copy the data
	self.plot.setCurveData(cSin, x, y)
	self.plot.setCurveData(cCos, x, z)
	
	# insert a horizontal marker at y = 0
	mY = self.plot.insertLineMarker('y = 0', QwtPlot.yLeft)
	self.plot.setMarkerYPos(mY, 0.0)

	# insert a vertical marker at x = 2 pi
	mX = self.plot.insertLineMarker('x = 2 pi', QwtPlot.xBottom)
	self.plot.setMarkerXPos(mX, 6.284)
	
	# set axis titles
	self.plot.setAxisTitle(QwtPlot.xBottom, 'x -->')
	self.plot.setAxisTitle(QwtPlot.yLeft, 'y -->')
	
	# enable show the legend
	self.plot.enableLegend(1)
	
    def resizeEvent(self, e):
    	self.plot.resize(e.size())
	self.plot.move(0,0)

# admire	
app = QApplication(sys.argv)
demo = SimpleDemo()
app.setMainWidget(demo)
demo.show()
app.exec_loop()




