#!/usr/bin/env python

import os, re, sys
from glob import glob
from os.path import basename, exists, join


def replacer(matchObj):
    if matchObj.group(2) == '*args':
        return (
            "%(head)s\n"
            "%(tabs)s\tfor key in kwargs.keys():\n"
            "%(tabs)s\t\tmethod = getattr(self, key)\n" 
            "%(tabs)s\t\tif type(kwargs[key]) == types.TupleType:\n" 
            "%(tabs)s\t\t\tapply(method,kwargs[key])\n"
            "%(tabs)s\t\telse:\n"
            "%(tabs)s\t\t\tmethod(kwargs[key])\n" %
            { 'head' : re.sub('\*args', '*args,**kwargs', matchObj.group(0)),
              'tabs' : matchObj.group(1) } )


def keywords(name, text):
    library = os.path.basename(name).split('.')[0]
    initRE = re.compile(r'(\t+)def __init__\(self,(\*args)\):\n'
                        '(\t+)lib%sc\.sipCallCtor\(\d+,self,args\)' % library)
    text = re.sub("\nimport lib%s" % library,
                  "\nimport types\nimport lib%s" % library, text)
    text = re.sub(initRE, replacer, text)
    return text


# Windows and Unix behave differently: Unix does not need os.remove()
def backup(source, extension):
    target = source + extension
    if exists(target):
        os.remove(target)
    os.rename(source, target)


def fix(sip_version, dir, name):
    print '...fixing by means of post_sip.fix(sip_version, dir, name)'
    
    cpp_module = join(dir, '%scmodule.cpp' % name)
    print '...adding "import_array();" to %s' % cpp_module 
    file = open(cpp_module, 'r')
    text = file.read()
    file.close()
    text = text.replace('\tPy_InitModule("lib%sc",methods);' % name,
                        '\tPy_InitModule("lib%sc",methods);'
                        '\n\timport_array();' % name)
    backup(cpp_module, '.numpy')
    file = open(cpp_module, 'w')
    file.write(text)
    file.close()

    py_wrapper = join(dir, '%s.py' % name)
    print '...fixing the keyword arguments in the Python constructors'
    file = open(py_wrapper, 'r')
    text = file.read()
    file.close()
    text = keywords(name, text)
    backup(py_wrapper, '.keywords')
    file = open(py_wrapper, 'w')
    file.write(text)
    file.close()

    if sip_version == '2.5':
        print '...fixing the sip include bugs'
        todo = [('sipqwtQwtArrowButton.h',
                 'sipqtQPushButton.h',
                 ['sipqtQButton.h']),
                ('sipqwtQwtLegend.h',
                 'sipqtQTable.h',
                 ['sipqtQFrame.h', 'sipqtQScrollView.h']),
                ]

        for header, where, bugs in todo:
            filename = join(dir, header)
            file = open(filename, 'r')
            text = file.read()
            file.close()
            for bug in bugs:
                text = text.replace('#include "%s"' % where,
                                    '#include "%s" // fixing sip bugs!\n'
                                    '#include "%s"' % (bug, where))
            backup(filename, '.include')
            file = open(filename, 'w')
            file.write(text)
            file.close()


if __name__=='__main__':
    if len(sys.argv) != 4:
        print "Usage: postsip.py 'sip_version' 'directory' 'name'"
        print "- 'sip_version' is obtained by sip -V"
        print "- 'directory' contains the sip-generated code"
        print "- 'name' is the PyQt module name" 
        sys.exit(1)

    fix(sys.argv[1], sys.argv[2], sys.argv[3])

    
